# Flask-WangEditor

wangEditor integration for Flask,a more simple and concies editor

## Links

* [Documentation #!todo](#todo)


## License

This project is licensed under the MIT License (see the `LICENSE` file for details).
